# DiscountLevel

The level of the discount. Values: `RatePlan`, `Subscription`, `Account`.  For example, if the value of this field is `subscription` and the value of the `applyDiscountTo` field is `RECURRING`, the discount charge applies to all recurring charges in the same subscription as the discount charge. 

## Enum

* `RATEPLAN` (value: `'rateplan'`)

* `SUBSCRIPTION` (value: `'subscription'`)

* `ACCOUNT` (value: `'account'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


